@@ -290,7 +290,7 @@ void CollectForOutput::processItem(PageItem *ite)
 	{
 		PageItem_OSGFrame *osgframe = ite->asOSGFrame();
 		QString ofName(osgframe->modelFile);
-		QFileInfo itf = QFileInfo(ofName);
+		QFileInfo itf(ofName);
 		if (!itf.exists())
 		{
 			ofName = QDir::toNativeSeparators(PrefsManager::instance().documentDir() + "/" + ofName);
@@ -458,7 +458,7 @@ bool CollectForOutput::collectProfiles()
 	int c = 0;
 	for (auto it = docProfiles.cbegin(); it != docProfiles.cend(); ++it)
 	{
-		QString oldFile(it.value());
+		QString oldFile(it.value().file);
 		QString outFile(m_outputDirectory + "profiles/" + QFileInfo(oldFile).fileName());
 		bool success = copyFileAtomic(oldFile, outFile);
 		if (!success)
