@@ -107,11 +107,10 @@ CgmPlug::CgmPlug(ScribusDoc* doc, int flags)
 
 QImage CgmPlug::readThumbnail(const QString& fName)
 {
-	QFileInfo fi = QFileInfo(fName);
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
-	double b, h;
-	b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
-	h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
+	QFileInfo fi(fName);
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
+	double b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
+	double h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
 	docWidth = b;
 	docHeight = h;
 	progressDialog = nullptr;
@@ -169,16 +168,15 @@ bool CgmPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 	importerFlags = flags;
 	cancel = false;
-	double b, h;
 	bool ret = false;
 	CustColors.clear();
-	QFileInfo fi = QFileInfo(fNameIn);
+	QFileInfo fi(fNameIn);
 	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
 	if (showProgress)
 	{
 		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
@@ -199,15 +197,13 @@ bool CgmPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	else
 		progressDialog = nullptr;
 /* Set default Page to size defined in Preferences */
-	b = 0.0;
-	h = 0.0;
 	if (progressDialog)
 	{
 		progressDialog->setOverallProgress(1);
 		qApp->processEvents();
 	}
-	b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
-	h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
+	double b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
+	double h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
 	docWidth = b;
 	docHeight = h;
 	baseX = 0;
@@ -953,7 +949,7 @@ void CgmPlug::decodeClass2(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF max, min;
 		max = getBinaryCoords(ts, true);
 		min = getBinaryCoords(ts, true);
-		QRectF vd = QRectF(max, min);
+		QRectF vd(max, min);
 		vcdFlippedV = (vd.height() > 0);
 		vcdFlippedH = (vd.width() < 0);
 		vd = vd.normalized();
@@ -1087,7 +1083,7 @@ void CgmPlug::decodeClass3(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF max, min;
 		max = getBinaryCoords(ts);
 		min = getBinaryCoords(ts);
-		QRectF vd = QRectF(max, min);
+		QRectF vd(max, min);
 		vd = vd.normalized();
 		double w = convertCoords(vd.width());
 		double h = convertCoords(vd.height());
@@ -1429,8 +1425,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		}
 		ts >> mode;
 		int bytesRead = ts.device()->pos() - pos;
-		QLineF pr = QLineF(p, r);
-		QLineF rq = QLineF(r, q);
+		QLineF pr(p, r);
+		QLineF rq(r, q);
 		double originX = p.x();
 		double originY = p.y();
 		bool flipX = false;
@@ -1586,10 +1582,9 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 	}
 	else if (elemID == 11)
 	{
-		QPointF max, min;
-		max = getBinaryCoords(ts);
-		min = getBinaryCoords(ts);
-		QRectF vd = QRectF(max, min);
+		QPointF max = getBinaryCoords(ts);
+		QPointF min = getBinaryCoords(ts);
+		QRectF vd(max, min);
 		vd = vd.normalized();
 		double w = convertCoords(vd.width());
 		double h = convertCoords(vd.height());
@@ -1632,17 +1627,17 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF pStart = convertCoords(getBinaryCoords(ts));
 		QPointF pInter = convertCoords(getBinaryCoords(ts));
 		QPointF pEnd = convertCoords(getBinaryCoords(ts));
-		QLineF s_e = QLineF(pStart, pEnd);
+		QLineF s_e(pStart, pEnd);
 		QLineF n_s = s_e.normalVector();
 		n_s.translate(s_e.pointAt(0.5) - s_e.p1());
-		QLineF s_i = QLineF(pStart, pInter);
+		QLineF s_i(pStart, pInter);
 		QLineF n_i = s_i.normalVector();
 		n_i.translate(s_i.pointAt(0.5) - s_i.p1());
 		QPointF center;
 		if (n_s.intersects(n_i, &center) != QLineF::NoIntersection)
 		{
-			QLineF rad1 = QLineF(center, pStart);
-			QLineF rad3 = QLineF(center, pInter);
+			QLineF rad1(center, pStart);
+			QLineF rad3(center, pInter);
 			double radius = rad1.length();
 			Coords.resize(0);
 			Coords.svgInit();
@@ -1680,17 +1675,17 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF pEnd = convertCoords(getBinaryCoords(ts));
 		quint16 mode;
 		ts >> mode;
-		QLineF s_e = QLineF(pStart, pEnd);
+		QLineF s_e(pStart, pEnd);
 		QLineF n_s = s_e.normalVector();
 		n_s.translate(s_e.pointAt(0.5) - s_e.p1());
-		QLineF s_i = QLineF(pStart, pInter);
+		QLineF s_i(pStart, pInter);
 		QLineF n_i = s_i.normalVector();
 		n_i.translate(s_i.pointAt(0.5) - s_i.p1());
 		QPointF center;
 		if (n_s.intersects(n_i, &center) != QLineF::NoIntersection)
 		{
-			QLineF rad1 = QLineF(center, pStart);
-			QLineF rad3 = QLineF(center, pInter);
+			QLineF rad1(center, pStart);
+			QLineF rad3(center, pInter);
 			double radius = rad1.length();
 			Coords.resize(0);
 			Coords.svgInit();
@@ -1742,8 +1737,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
-		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
+		QLineF stv(cx, cy, cx + sx, cy + sy);
+		QLineF env(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		if (qFuzzyCompare(sx, ex) && qFuzzyCompare(sy, ey))
 		{
@@ -1799,8 +1794,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
-		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
+		QLineF stv(cx, cy, cx + sx, cy + sy);
+		QLineF env(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		if (qFuzzyCompare(sx, ex) && qFuzzyCompare(sy, ey))
 		{
@@ -1886,8 +1881,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF r2 = getBinaryCoords(ts);
 		double r2x = convertCoords(r2.x());
 		double r2y = convertCoords(r2.y());
-		QLineF dstX = QLineF(cx, cy, r1x, r1y);
-		QLineF dstY = QLineF(cx, cy, r2x, r2y);
+		QLineF dstX(cx, cy, r1x, r1y);
+		QLineF dstY(cx, cy, r2x, r2y);
 		double distX = dstX.length();
 		double distY = dstY.length();
 		double rotB = dstX.angle();
@@ -1905,8 +1900,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
-		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
+		QLineF stv(cx, cy, cx + sx, cy + sy);
+		QLineF env(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		ell.addEllipse(QPointF(cx, cy), distX, distY);
 		ell.translate(-cx, -cy);
@@ -1990,8 +1985,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF r2 = getBinaryCoords(ts);
 		double r2x = convertCoords(r2.x());
 		double r2y = convertCoords(r2.y());
-		QLineF dstX = QLineF(cx, cy, r1x, r1y);
-		QLineF dstY = QLineF(cx, cy, r2x, r2y);
+		QLineF dstX(cx, cy, r1x, r1y);
+		QLineF dstY(cx, cy, r2x, r2y);
 		double distX = dstX.length();
 		double distY = dstY.length();
 		double rotB = dstX.angle();
@@ -2010,8 +2005,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
-		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
+		QLineF stv(cx, cy, cx + sx, cy + sy);
+		QLineF env(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		ell.addEllipse(QPointF(cx, cy), distX, distY);
 		ell.translate(-cx, -cy);
@@ -2440,8 +2435,8 @@ void CgmPlug::decodeClass5(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		double phy = convertCoords(getBinaryDistance(ts));
 		double pwx = convertCoords(getBinaryDistance(ts));
 		double pwy = convertCoords(getBinaryDistance(ts));
-		QLineF hp = QLineF(0, 0, phx, phy);
-		QLineF wp = QLineF(0, 0, pwx, pwy);
+		QLineF hp(0, 0, phx, phy);
+		QLineF wp(0, 0, pwx, pwy);
 		patternScaleX = wp.length();
 		patternScaleY = hp.length();
 	//	qDebug() << "PATTERN SIZE" << wp.length() << hp.length();
