@@ -61,8 +61,8 @@ PctPlug::PctPlug(ScribusDoc* doc, int flags)
 
 QImage PctPlug::readThumbnail(const QString& fName)
 {
-	QFileInfo fi = QFileInfo(fName);
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
+	QFileInfo fi(fName);
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
 	double b {0.0};
 	double h {0.0};
 	double x {0.0};
@@ -131,14 +131,14 @@ bool PctPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	cancel = false;
 	bool ret = false;
 	CustColors.clear();
-	QFileInfo fi = QFileInfo(fNameIn);
-	if ( !ScCore->usingGUI() )
+	QFileInfo fi(fNameIn);
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
-	if ( showProgress )
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
+	if (showProgress)
 	{
 		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
@@ -1598,7 +1598,7 @@ void PctPlug::handleShortLine(QDataStream &ts)
 		currentPoint = QPoint(x * resX, y * resY);
 		return;
 	}
-	QPoint s = QPoint(x * resX, y * resY);
+	QPoint s(x * resX, y * resY);
 	if (currentPoint != s)
 	{
 		handleLineModeEnd();
@@ -1630,7 +1630,7 @@ void PctPlug::handleLine(QDataStream &ts)
 	qint16 x1, x2, y1, y2;
 	ts >> y1 >> x1;
 	ts >> y2 >> x2;
-	QPoint s = QPoint(x1 * resX, y1 * resY);
+	QPoint s(x1 * resX, y1 * resY);
 	if (currentPoint != s)
 	{
 		handleLineModeEnd();
