@@ -108,11 +108,11 @@ double VivaPlug::parseUnit(const QString &unit)
 QImage VivaPlug::readThumbnail(const QString& fName)
 {
 	QImage tmp;
-	if ( !QFile::exists(fName) )
+	if (!QFile::exists(fName))
 		return QImage();
 	progressDialog = nullptr;
-	QFileInfo fi = QFileInfo(fName);
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
+	QFileInfo fi(fName);
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
 	docWidth = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
 	docHeight = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
 	m_Doc = new ScribusDoc();
@@ -205,14 +205,14 @@ bool VivaPlug::import(const QString& fNameIn, const TransactionSettings& trSetti
 	firstPage = true;
 	pagecount = 1;
 	mpagecount = 0;
-	QFileInfo fi = QFileInfo(fNameIn);
-	if ( !ScCore->usingGUI() )
+	QFileInfo fi(fNameIn);
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
-	if ( showProgress )
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
+	if (showProgress)
 	{
 		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
@@ -1197,7 +1197,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 						QDomElement eo = spo.toElement();
 						if (eo.tagName() == "vo:point")
 						{
-							FPoint pp = FPoint(parseUnit(eo.attribute("vo:x", "0")), parseUnit(eo.attribute("vo:y", "0")));
+							FPoint pp(parseUnit(eo.attribute("vo:x", "0")), parseUnit(eo.attribute("vo:y", "0")));
 							if (eo.hasAttribute("vo:control"))
 							{
 								if ((eo.attribute("vo:control") == "constraint-before") || (eo.attribute("vo:control") == "before"))
@@ -1304,7 +1304,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 						else if (spo.tagName() == "uni:applyElementOpacity")
 							shadowObjTrans = (spo.text() == "true");
 					}
-					QLineF oLine = QLineF(0, 0, shadowOffset, 0);
+					QLineF oLine(0, 0, shadowOffset, 0);
 					oLine.setAngle(shadowAngle - 180.0);
 					shadowX = oLine.p2().x();
 					shadowY = oLine.p2().y();
@@ -1536,7 +1536,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 				QString gradColor1Str = colorStops[1]->name;
 				QColor gradColor1 = colorStops[1]->color;
 				item->meshGradientPatches.clear();
-				FPoint center = FPoint(item->width() / 2.0, item->height() / 2.0);
+				FPoint center(item->width() / 2.0, item->height() / 2.0);
 				MeshPoint cP;
 				cP.resetTo(center);
 				cP.transparency = 1.0;
@@ -1578,7 +1578,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 				item->GrControl4 = FPoint(0, item->height());
 				if (gradientAngle != 0)
 				{
-					QLineF gradientVector = QLineF(item->width() / 2.0, item->height() / 2.0, 0, 0);
+					QLineF gradientVector(item->width() / 2.0, item->height() / 2.0, 0, 0);
 					gradientVector.setLength(gradientVector.length() + 1);
 					gradientVector.setAngle(gradientVector.angle() + gradientAngle);
 					QPointF g1 = intersectBoundingRect(item, gradientVector);
