@@ -263,7 +263,7 @@ PyObject *scribus_setlayervisible(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	}
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -294,7 +294,7 @@ PyObject *scribus_setlayerprintable(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	}
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -325,7 +325,7 @@ PyObject *scribus_setlayerlocked(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	}
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -356,7 +356,7 @@ PyObject *scribus_setlayeroutlined(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	}
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -387,7 +387,7 @@ PyObject *scribus_setlayerflow(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	}
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -418,7 +418,7 @@ PyObject *scribus_setlayerblendmode(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	}
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -449,7 +449,7 @@ PyObject *scribus_setlayertransparency(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	}
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -480,7 +480,7 @@ PyObject *scribus_islayervisible(PyObject* /* self */, PyObject* args)
 	}
 	int i = 0;
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -511,7 +511,7 @@ PyObject *scribus_islayerprintable(PyObject* /* self */, PyObject* args)
 	}
 	int i = 0;
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -542,11 +542,11 @@ PyObject *scribus_islayerlocked(PyObject* /* self */, PyObject* args)
 	}
 	int i = 0;
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
-			i = static_cast<int>(ScCore->primaryMainWindow()->doc->Layers[lam].isEditable);
+			i = static_cast<int>(!ScCore->primaryMainWindow()->doc->Layers[lam].isEditable);
 			found = true;
 			break;
 		}
@@ -573,7 +573,7 @@ PyObject *scribus_islayeroutlined(PyObject* /* self */, PyObject* args)
 	}
 	int i = 0;
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -604,7 +604,7 @@ PyObject *scribus_islayerflow(PyObject* /* self */, PyObject* args)
 	}
 	int i = 0;
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -635,7 +635,7 @@ PyObject *scribus_getlayerblendmode(PyObject* /* self */, PyObject* args)
 	}
 	int i = 0;
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -666,7 +666,7 @@ PyObject *scribus_getlayertransparency(PyObject* /* self */, PyObject* args)
 	}
 	double i = 1.0;
 	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
+	for (int lam = 0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); lam++)
 	{
 		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
 		{
@@ -696,37 +696,30 @@ PyObject *scribus_deletelayer(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot have an empty layer name.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	if (ScCore->primaryMainWindow()->doc->Layers.count() == 1)
+
+	auto* currentDoc = ScCore->primaryMainWindow()->doc;
+	if (currentDoc->Layers.count() == 1)
 	{
 		PyErr_SetString(ScribusException, QObject::tr("Cannot remove the last layer.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	bool found = false;
-	for (int lam=0; lam < ScCore->primaryMainWindow()->doc->Layers.count(); ++lam)
+
+	const ScLayer* pLayer = currentDoc->Layers.layerByName(QString::fromUtf8(name.c_str()));
+	if (!pLayer)
 	{
-		if (ScCore->primaryMainWindow()->doc->Layers[lam].Name == QString::fromUtf8(name.c_str()))
-		{
-			ScLayer it2 = ScCore->primaryMainWindow()->doc->Layers.at(lam);
-			int num2 = it2.ID;
-			if (!num2)
-			{
-				// FIXME: WTF DOES THIS DO?
-				Py_INCREF(Py_None);
-				return Py_None;
-			}
-			ScCore->primaryMainWindow()->doc->removeLayer(num2);
-			ScCore->primaryMainWindow()->doc->Layers.removeLayerByID(num2);
-			ScCore->primaryMainWindow()->doc->setActiveLayer(0);
-			ScCore->primaryMainWindow()->changeLayer(0);
-			found = true;
-			break;
-		}
-	}
-	if (!found)
-	{
-		PyErr_SetString(NotFoundError, QObject::tr("Layer not found.","python error").toLocal8Bit().constData());
+		PyErr_SetString(NotFoundError, QObject::tr("Layer not found.", "python error").toLocal8Bit().constData());
 		return nullptr;
 	}
+
+	int num2 = pLayer->ID;
+	if (!num2)
+		Py_RETURN_NONE;
+
+	currentDoc->removeLayer(num2);
+	currentDoc->Layers.removeLayerByID(num2);
+	currentDoc->setActiveLayer(0);
+	ScCore->primaryMainWindow()->changeLayer(0);
+
 	Py_RETURN_NONE;
 }
 
