@@ -143,12 +143,14 @@ NewDocDialog::NewDocDialog(QWidget* parent, const QStringList& recentDocs, bool
 	}
 	QSpacerItem* spacer = new QSpacerItem( 2, 2, QSizePolicy::Expanding, QSizePolicy::Minimum );
 	Layout1->addItem( spacer );
-	OKButton = new QPushButton( CommonStrings::tr_OK, this );
-	OKButton->setDefault( true );
-	Layout1->addWidget( OKButton );
-	CancelB = new QPushButton( CommonStrings::tr_Cancel, this );
-	CancelB->setAutoDefault( false );
-	Layout1->addWidget( CancelB );
+	buttonBox = new QDialogButtonBox();
+	Layout1->addWidget(buttonBox);
+	okButton = new QPushButton( CommonStrings::tr_OK, this );
+	okButton->setDefault( true );
+	buttonBox->addButton(okButton, QDialogButtonBox::AcceptRole);
+	cancelButton = new QPushButton( CommonStrings::tr_Cancel, this );
+	cancelButton->setAutoDefault( false );
+	buttonBox->addButton(cancelButton, QDialogButtonBox::RejectRole);
 	TabbedNewDocLayout->addLayout( Layout1 );
 	//tooltips
 	pageSizeComboBox->setToolTip( tr( "Document page size, either a standard size or a custom size" ) );
@@ -162,8 +164,8 @@ NewDocDialog::NewDocDialog(QWidget* parent, const QStringList& recentDocs, bool
 	Distance->setToolTip( tr( "Distance between automatically created columns" ) );
 
 	// signals and slots connections
-	connect( OKButton, SIGNAL( clicked() ), this, SLOT( ExitOK() ) );
-	connect( CancelB, SIGNAL( clicked() ), this, SLOT( reject() ) );
+	connect(buttonBox, SIGNAL(accepted()), this, SLOT(ExitOK()));
+	connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 	connect(pageSizeComboBox, SIGNAL(activated(const QString &)), this, SLOT(setPageSize(const QString &)));
 	connect(pageOrientationComboBox, SIGNAL(activated(int)), this, SLOT(setOrientation(int)));
 	connect(unitOfMeasureComboBox, SIGNAL(activated(int)), this, SLOT(setUnit(int)));
@@ -197,7 +199,7 @@ void NewDocDialog::createNewDocPage()
 	for (int i = 0; i < prefsManager.appPrefs.pageSets.count(); ++i)
 	{
 		QListWidgetItem *ic;
-		QString psname=CommonStrings::translatePageSetString(prefsManager.appPrefs.pageSets[i].Name);
+		QString psname = CommonStrings::translatePageSetString(prefsManager.appPrefs.pageSets[i].Name);
 		if (i == 0)
 		{
 			ic = new QListWidgetItem( IconManager::instance().loadIcon("32/page-simple.png"), psname, layoutsView );
@@ -437,8 +439,8 @@ void NewDocDialog::setWidth(double)
 {
 	m_pageWidth = widthSpinBox->value() / m_unitRatio;
 	marginGroup->setPageWidth(m_pageWidth);
-	QString psText=pageSizeComboBox->currentText();
-	if (psText!=CommonStrings::trCustomPageSize && psText!=CommonStrings::customPageSize)
+	QString psText = pageSizeComboBox->currentText();
+	if (psText != CommonStrings::trCustomPageSize && psText != CommonStrings::customPageSize)
 		pageSizeComboBox->setCurrentIndex(pageSizeComboBox->count() - 1);
 	int newOrientation = (widthSpinBox->value() > heightSpinBox->value()) ? landscapePage : portraitPage;
 	if (newOrientation != m_orientation)
@@ -454,8 +456,8 @@ void NewDocDialog::setHeight(double)
 {
 	m_pageHeight = heightSpinBox->value() / m_unitRatio;
 	marginGroup->setPageHeight(m_pageHeight);
-	QString psText=pageSizeComboBox->currentText();
-	if (psText!=CommonStrings::trCustomPageSize && psText!=CommonStrings::customPageSize)
+	QString psText = pageSizeComboBox->currentText();
+	if (psText != CommonStrings::trCustomPageSize && psText != CommonStrings::customPageSize)
 		pageSizeComboBox->setCurrentIndex(pageSizeComboBox->count() - 1);
 	int newOrientation = (widthSpinBox->value() > heightSpinBox->value()) ? landscapePage : portraitPage;
 	if (newOrientation != m_orientation)
@@ -639,7 +641,7 @@ void NewDocDialog::setSize(const QString& gr)
 
 	disconnect(widthSpinBox, SIGNAL(valueChanged(double)), this, SLOT(setWidth(double)));
 	disconnect(heightSpinBox, SIGNAL(valueChanged(double)), this, SLOT(setHeight(double)));
-	if (gr==CommonStrings::trCustomPageSize || gr==CommonStrings::customPageSize)
+	if (gr == CommonStrings::trCustomPageSize || gr == CommonStrings::customPageSize)
 	{
 		widthSpinBox->setEnabled(true);
 		heightSpinBox->setEnabled(true);
@@ -651,7 +653,9 @@ void NewDocDialog::setSize(const QString& gr)
 		{
 			m_pageWidth = ps2.width();
 			m_pageHeight = ps2.height();
-		} else {
+		}
+		else
+		{
 			m_pageWidth = ps2.height();
 			m_pageHeight = ps2.width();
 		}
@@ -690,7 +694,7 @@ void NewDocDialog::adjustTitles(int tab)
 		setWindowTitle(tr("Open Recent Document"));
 	else
 		setWindowTitle(tr("New Document"));
-	OKButton->setEnabled(tab!=2);
+	okButton->setEnabled(tab!=2);
 }
 
 void NewDocDialog::locationDropped(const QString& fileUrl)
@@ -742,5 +746,5 @@ void NewDocDialog::gotoHomeDirectory()
 
 void NewDocDialog::openFileDialogFileClicked(const QString& path)
 {
-	OKButton->setEnabled(!path.isEmpty());
+	okButton->setEnabled(!path.isEmpty());
 }
